#This procedure writes each segment of a file out into a separate file,
#where a segment is a section containing no silence longer than the
#current threshold. It sets the window at the beginning of the file
#and then advances the window using the command WindowForwardSilence.
#Before writing out the window, it moves the edges of the region to be
#written to zero crossings.

#Simple version
proc ChopFile {fn} {
    LoadSoundFile $fn;
    set SoundFileLength [TellSoundFileLengthSamples];
    WindowBounds 1 2
    while {[TellWindowRightEdgeSamples] < $SoundFileLength} {
	if { [WindowForwardSilence]} {
	    set wle [PreviousZeroCrossingLeft [TellWindowLeftEdgeSamples]];
	    if {$wle < 0} {set wle [TellWindowLeftEdgeSamples]}
	    set wre [NextZeroCrossingRight [TellWindowRightEdgeSamples]];
	    if {$wre < 0} {set wre [TellWindowRightEdgeSamples]}
	    set fn [NextOutputFile];
	    WriteRegionToFile $wle $wre $fn;
	    Puts [format "Wrote region \[%3.3f,%3.3f\] to file %s" \
		      [SamplesToSeconds $wle] \
		      [SamplesToSeconds $wre] $fn]
	} else {
	    break;
	}
    }
}


#This version is intended to run with the GUI present and lets you watch what
#it is doing.  It updates the display and pauses each time it advances
#the window.
proc ChopFileVisualize {fn} {
    LoadSoundFile $fn;
    set SoundFileLength [TellSoundFileLengthSamples];
    WindowBounds 1 2
    while {[TellWindowRightEdgeSamples] < $SoundFileLength} {
	if { [WindowForwardSilence]} {
	    update;
	    Puts [format "window \[%3.3f,%3.3f\]" \
		      [SamplesToSeconds [TellWindowLeftEdgeSamples]] \
		      [SamplesToSeconds [TellWindowRightEdgeSamples]]]
	    after 3000;			# Wait 3 seconds
	    set wle [PreviousZeroCrossingLeft [TellWindowLeftEdgeSamples]];
	    if {$wle < 0} {set wle [TellWindowLeftEdgeSamples]}
	    set wre [NextZeroCrossingRight [TellWindowRightEdgeSamples]];
	    if {$wre < 0} {set wre [TellWindowRightEdgeSamples]}
	    set fn [NextOutputFile];
	    WriteRegionToFile $wle $wre $fn;
	    Puts [format "Wrote region \[%3.3f,%3.3f\] to file %s\n" \
		      [SamplesToSeconds $wle] \
		      [SamplesToSeconds $wre] $fn]
	} else {
	    break;
	}
    }
}

SilenceThreshold 0.5;			# Ignore silences of less than 500 ms.
OutFilePrefix TestFragment;		# Set prefix for fragment file
#Uncommment one or the other of the following commands
#ChopFile TestFile.wav
#ChopFileVisualize TestFile.wav






